@@ -1,7 +1,4 @@
 """A module for Split.io Factories."""
-from __future__ import absolute_import, division, print_function, unicode_literals
-
-
 import logging
 import threading
 from collections import Counter
@@ -11,21 +8,17 @@ from enum import Enum
 from splitio.client.client import Client
 from splitio.client import input_validator
 from splitio.client.manager import SplitManager
-from splitio.client.config import sanitize as sanitize_config, DEFAULT_DATA_SAMPLING
+from splitio.client.config import sanitize as sanitize_config
 from splitio.client import util
 from splitio.client.listener import ImpressionListenerWrapper
-from splitio.client.wrapper import SplitFactoryWrapped
 from splitio.engine.impressions import Manager as ImpressionsManager
 
 # Storage
 from splitio.storage.inmemmory import InMemorySplitStorage, InMemorySegmentStorage, \
-    InMemoryImpressionStorage, InMemoryEventStorage
+    InMemoryImpressionStorage, InMemoryEventStorage, InMemoryTelemetryStorage
 from splitio.storage.adapters import redis
 from splitio.storage.redis import RedisSplitStorage, RedisSegmentStorage, RedisImpressionsStorage, \
-    RedisEventsStorage
-from splitio.storage.adapters.uwsgi_cache import get_uwsgi
-from splitio.storage.uwsgi import UWSGIEventStorage, UWSGIImpressionStorage, UWSGISegmentStorage, \
-    UWSGISplitStorage
+    RedisEventsStorage, RedisTelemetryStorage
 
 # APIs
 from splitio.api.client import HttpClient
@@ -33,6 +26,7 @@ from splitio.api.splits import SplitsAPI
 from splitio.api.segments import SegmentsAPI
 from splitio.api.impressions import ImpressionsAPI
 from splitio.api.events import EventsAPI
+from splitio.api.telemetry import TelemetryAPI
 from splitio.api.auth import AuthAPI
 
 # Tasks
@@ -40,6 +34,7 @@ from splitio.tasks.split_sync import SplitSynchronizationTask
 from splitio.tasks.segment_sync import SegmentSynchronizationTask
 from splitio.tasks.impressions_sync import ImpressionsSyncTask, ImpressionsCountSyncTask
 from splitio.tasks.events_sync import EventsSyncTask
+from splitio.tasks.telemetry_sync import TelemetrySynchronizationTask
 
 # Synchronizer
 from splitio.sync.synchronizer import SplitTasks, SplitSynchronizers, Synchronizer, \
@@ -49,18 +44,19 @@ from splitio.sync.split import SplitSynchronizer, LocalSplitSynchronizer
 from splitio.sync.segment import SegmentSynchronizer
 from splitio.sync.impression import ImpressionSynchronizer, ImpressionsCountSynchronizer
 from splitio.sync.event import EventSynchronizer
+from splitio.sync.telemetry import TelemetrySynchronizer
 
 # Recorder
 from splitio.recorder.recorder import StandardRecorder, PipelinedRecorder
 
 # Localhost stuff
-from splitio.client.localhost import LocalhostEventsStorage, LocalhostImpressionsStorage
+from splitio.client.localhost import LocalhostEventsStorage, LocalhostImpressionsStorage, \
+    LocalhostTelemetryStorage
 
 
 _LOGGER = logging.getLogger(__name__)
 _INSTANTIATED_FACTORIES = Counter()
 _INSTANTIATED_FACTORIES_LOCK = threading.RLock()
-_MIN_DEFAULT_DATA_SAMPLING_ALLOWED = 0.1  # 10%
 
 
 class Status(Enum):
@@ -263,6 +259,7 @@ class SplitFactory(object):  # pylint: disable=too-many-instance-attributes
         sdk_ready_flag = threading.Event()
         self._sdk_internal_ready_flag = sdk_ready_flag
         self._sync_manager._ready_flag = sdk_ready_flag
+        self._get_storage('telemetry').clear()
         self._get_storage('impressions').clear()
         self._get_storage('events').clear()
         initialization_thread = threading.Thread(
@@ -309,6 +306,7 @@ def _build_in_memory_factory(api_key, cfg, sdk_url=None, events_url=None,  # pyl
         'segments': SegmentsAPI(http_client, api_key, sdk_metadata),
         'impressions': ImpressionsAPI(http_client, api_key, sdk_metadata, cfg['impressionsMode']),
         'events': EventsAPI(http_client, api_key, sdk_metadata),
+        'telemetry': TelemetryAPI(http_client, api_key, sdk_metadata)
     }
 
     if not input_validator.validate_apikey_type(apis['segments']):
@@ -319,6 +317,7 @@ def _build_in_memory_factory(api_key, cfg, sdk_url=None, events_url=None,  # pyl
         'segments': InMemorySegmentStorage(),
         'impressions': InMemoryImpressionStorage(cfg['impressionsQueueSize']),
         'events': InMemoryEventStorage(cfg['eventsQueueSize']),
+        'telemetry': InMemoryTelemetryStorage()
     }
 
     imp_manager = ImpressionsManager(
@@ -332,6 +331,7 @@ def _build_in_memory_factory(api_key, cfg, sdk_url=None, events_url=None,  # pyl
         ImpressionSynchronizer(apis['impressions'], storages['impressions'],
                                cfg['impressionsBulkSize']),
         EventSynchronizer(apis['events'], storages['events'], cfg['eventsBulkSize']),
+        TelemetrySynchronizer(apis['telemetry'], storages['telemetry']),
         ImpressionsCountSynchronizer(apis['impressions'], imp_manager),
     )
 
@@ -349,6 +349,10 @@ def _build_in_memory_factory(api_key, cfg, sdk_url=None, events_url=None,  # pyl
             cfg['impressionsRefreshRate'],
         ),
         EventsSyncTask(synchronizers.events_sync.synchronize_events, cfg['eventsPushRate']),
+        TelemetrySynchronizationTask(
+            synchronizers.telemetry_sync.synchronize_telemetry,
+            cfg['metricsRefreshRate'],
+        ),
         ImpressionsCountSyncTask(synchronizers.impressions_count_sync.synchronize_counters)
     )
 
@@ -358,13 +362,14 @@ def _build_in_memory_factory(api_key, cfg, sdk_url=None, events_url=None,  # pyl
 
     sdk_ready_flag = threading.Event() if not preforked_initialization else None
     manager = Manager(sdk_ready_flag, synchronizer, apis['auth'], cfg['streamingEnabled'],
-                      streaming_api_base_url)
+                      sdk_metadata, streaming_api_base_url, api_key[-4:])
 
     storages['events'].set_queue_full_hook(tasks.events_task.flush)
     storages['impressions'].set_queue_full_hook(tasks.impressions_task.flush)
 
     recorder = StandardRecorder(
         imp_manager,
+        storages['telemetry'],
         storages['events'],
         storages['impressions'],
     )
@@ -394,48 +399,16 @@ def _build_redis_factory(api_key, cfg):
         'segments': RedisSegmentStorage(redis_adapter),
         'impressions': RedisImpressionsStorage(redis_adapter, sdk_metadata),
         'events': RedisEventsStorage(redis_adapter, sdk_metadata),
+        'telemetry': RedisTelemetryStorage(redis_adapter, sdk_metadata)
     }
-    data_sampling = cfg.get('dataSampling', DEFAULT_DATA_SAMPLING)
-    if data_sampling < _MIN_DEFAULT_DATA_SAMPLING_ALLOWED:
-        _LOGGER.warning("dataSampling cannot be less than %f, defaulting to minimum",
-                        _MIN_DEFAULT_DATA_SAMPLING_ALLOWED)
-        data_sampling = _MIN_DEFAULT_DATA_SAMPLING_ALLOWED
     recorder = PipelinedRecorder(
         redis_adapter.pipeline,
         ImpressionsManager(cfg['impressionsMode'], False,
                            _wrap_impression_listener(cfg['impressionListener'], sdk_metadata)),
-        storages['events'],
-        storages['impressions'],
-        data_sampling,
-    )
-    return SplitFactory(
-        api_key,
-        storages,
-        cfg['labelsEnabled'],
-        recorder,
-    )
-
-
-def _build_uwsgi_factory(api_key, cfg):
-    """Build and return a split factory with redis-based storage."""
-    sdk_metadata = util.get_metadata(cfg)
-    uwsgi_adapter = get_uwsgi()
-    storages = {
-        'splits': UWSGISplitStorage(uwsgi_adapter),
-        'segments': UWSGISegmentStorage(uwsgi_adapter),
-        'impressions': UWSGIImpressionStorage(uwsgi_adapter),
-        'events': UWSGIEventStorage(uwsgi_adapter),
-    }
-    recorder = StandardRecorder(
-        ImpressionsManager(cfg['impressionsMode'], True,
-                           _wrap_impression_listener(cfg['impressionListener'], sdk_metadata)),
+        storages['telemetry'],
         storages['events'],
         storages['impressions'],
     )
-    _LOGGER.warning(
-        "Beware: uwsgi-cache based operation mode is soon to be deprecated. Please consider " +
-        "redis if you need a centralized point of syncrhonization, or in-memory (with preforking " +
-        "support enabled) if running uwsgi with a master and several http workers)")
     return SplitFactory(
         api_key,
         storages,
@@ -451,26 +424,29 @@ def _build_localhost_factory(cfg):
         'segments': InMemorySegmentStorage(),  # not used, just to avoid possible future errors.
         'impressions': LocalhostImpressionsStorage(),
         'events': LocalhostEventsStorage(),
+        'telemetry': LocalhostTelemetryStorage()
     }
 
     synchronizers = SplitSynchronizers(
         LocalSplitSynchronizer(cfg['splitFile'], storages['splits']),
-        None, None, None, None,
+        None, None, None, None, None,
     )
 
     tasks = SplitTasks(
         SplitSynchronizationTask(
             synchronizers.split_sync.synchronize_splits,
             cfg['featuresRefreshRate'],
-        ), None, None, None, None,
+        ), None, None, None, None, None,
     )
 
+    sdk_metadata = util.get_metadata(cfg)
     ready_event = threading.Event()
     synchronizer = LocalhostSynchronizer(synchronizers, tasks)
-    manager = Manager(ready_event, synchronizer, None, False)
+    manager = Manager(ready_event, synchronizer, None, False, sdk_metadata)
     manager.start()
     recorder = StandardRecorder(
         ImpressionsManager(cfg['impressionsMode'], True, None),
+        storages['telemetry'],
         storages['events'],
         storages['impressions'],
     )
@@ -505,10 +481,6 @@ def get_factory(api_key, **kwargs):
                     "(Singleton pattern) and reusing it throughout your application."
                 )
 
-        config = kwargs.get('config', {})
-        if not config.get('evaluationsEnabled', True):
-            return SplitFactoryWrapped()
-
         config = sanitize_config(api_key, kwargs.get('config', {}))
 
         if config['operationMode'] == 'localhost-standalone':
@@ -517,9 +489,6 @@ def get_factory(api_key, **kwargs):
         if config['operationMode'] == 'redis-consumer':
             return _build_redis_factory(api_key, config)
 
-        if config['operationMode'] == 'uwsgi-consumer':
-            return _build_uwsgi_factory(api_key, config)
-
         return _build_in_memory_factory(
             api_key,
             config,
