@@ -1,14 +1,11 @@
 """Redis storage module."""
-from __future__ import absolute_import, division, print_function, \
-    unicode_literals
-
 import json
 import logging
 
 from splitio.models.impressions import Impression
 from splitio.models import splits, segments
 from splitio.storage import SplitStorage, SegmentStorage, ImpressionStorage, EventStorage, \
-    ImpressionPipelinedStorage
+    ImpressionPipelinedStorage, TelemetryStorage, TelemetryPipelinedStorage
 from splitio.storage.adapters.redis import RedisAdapterException
 from splitio.storage.adapters.cache_trait import decorate as add_cache, DEFAULT_MAX_AGE
 
@@ -528,3 +525,187 @@ class RedisEventsStorage(EventStorage):
         Clear data.
         """
         raise NotImplementedError('Not supported for redis.')
+
+
+class RedisTelemetryStorage(TelemetryStorage, TelemetryPipelinedStorage):
+    """Redis-based Telemetry storage."""
+
+    _LATENCY_KEY_TEMPLATE = "SPLITIO/{sdk}/{instance}/latency.{name}.bucket.{bucket}"
+    _COUNTER_KEY_TEMPLATE = "SPLITIO/{sdk}/{instance}/count.{name}"
+    _GAUGE_KEY_TEMPLATE = "SPLITIO/{sdk}/{instance}/gauge.{name}"
+
+    def __init__(self, redis_client, sdk_metadata):
+        """
+        Class constructor.
+
+        :param redis_client: Redis client or compliant interface.
+        :type redis_client: splitio.storage.adapters.redis.RedisAdapter
+        :param sdk_metadata: SDK & Machine information.
+        :type sdk_metadata: splitio.client.util.SdkMetadata
+        """
+        self._redis = redis_client
+        self._metadata = sdk_metadata
+
+    def _get_latency_key(self, name, bucket):
+        """
+        Instantiate and return the latency key template.
+
+        :param name: Name of the latency metric.
+        :type name: str
+        :param bucket: Number of bucket.
+        :type bucket: int
+
+        :return: Redis latency key.
+        :rtype: str
+        """
+        return self._LATENCY_KEY_TEMPLATE.format(
+            sdk=self._metadata.sdk_version,
+            instance=self._metadata.instance_name,
+            name=name,
+            bucket=bucket
+        )
+
+    def _get_counter_key(self, name):
+        """
+        Instantiate and return the counter key template.
+
+        :param name: Name of the counter metric.
+        :type name: str
+
+        :return: Redis counter key.
+        :rtype: str
+        """
+        return self._COUNTER_KEY_TEMPLATE.format(
+            sdk=self._metadata.sdk_version,
+            instance=self._metadata.instance_name,
+            name=name
+        )
+
+    def _get_gauge_key(self, name):
+        """
+        Instantiate and return the latency key template.
+
+        :param name: Name of the latency metric.
+        :type name: str
+
+        :return: Redis latency key.
+        :rtype: str
+        """
+        return self._GAUGE_KEY_TEMPLATE.format(
+            sdk=self._metadata.sdk_version,
+            instance=self._metadata.instance_name,
+            name=name,
+        )
+
+    def _wrap_latency(self, name, bucket):
+        """
+        Wrap latency to be stored.
+
+        :param name: Name of the latency metric.
+        :type name: str
+        :param value: Value of the latency metric.
+        :tyoe value: int
+
+        :return: Redis latency key.
+        :rtype: str
+        """
+        if not 0 <= bucket <= 21:
+            _LOGGER.error('Incorect bucket "%d" for latency "%s". Ignoring.', bucket, name)
+            return None
+
+        return self._get_latency_key(name, bucket)
+
+    def add_latency_to_pipe(self, name, bucket, pipe):
+        """
+        Add latency operation to pipeline
+
+        :param name: Name of the latency metric.
+        :type name: str
+        :param value: Value of the latency metric.
+        :tyoe value: int
+        :param pipe: Redis pipe.
+        :type pipe: redis.pipe
+        """
+        key = self._wrap_latency(name, bucket)
+        if key is None:
+            return
+        pipe.incr(key)
+
+    def inc_latency(self, name, bucket):
+        """
+        Add a latency.
+
+        :param name: Name of the latency metric.
+        :type name: str
+        :param value: Value of the latency metric.
+        :tyoe value: int
+        """
+        key = self._wrap_latency(name, bucket)
+        if key is None:
+            return
+        try:
+            self._redis.incr(key)
+        except RedisAdapterException:
+            _LOGGER.error('Something went wrong when trying to store latency in redis')
+            _LOGGER.debug('Error: ', exc_info=True)
+
+    def inc_counter(self, name):
+        """
+        Increment a counter.
+
+        :param name: Name of the counter metric.
+        :type name: str
+        """
+        key = self._get_counter_key(name)
+        try:
+            self._redis.incr(key)
+        except RedisAdapterException:
+            _LOGGER.error('Something went wrong when trying to increment counter in redis')
+            _LOGGER.debug('Error: ', exc_info=True)
+
+    def put_gauge(self, name, value):
+        """
+        Add a gauge metric.
+
+        :param name: Name of the gauge metric.
+        :type name: str
+        :param value: Value of the gauge metric.
+        :type value: int
+        """
+        key = self._get_gauge_key(name)
+        try:
+            self._redis.set(key, value)
+        except RedisAdapterException:
+            _LOGGER.error('Something went wrong when trying to set gauge in redis')
+            _LOGGER.debug('Error: ', exc_info=True)
+
+    def pop_counters(self):
+        """
+        Get all the counters.
+
+        :rtype: list
+        """
+        raise NotImplementedError('Only redis-consumer mode is supported.')
+
+    def pop_gauges(self):
+        """
+        Get all the gauges.
+
+        :rtype: list
+
+        """
+        raise NotImplementedError('Only redis-consumer mode is supported.')
+
+    def pop_latencies(self):
+        """
+        Get all latencies.
+
+        :rtype: list
+        """
+        raise NotImplementedError('Only redis-consumer mode is supported.')
+
+    def clear(self):
+        """
+        Clear data.
+        """
+        raise NotImplementedError('Not supported for redis.')
